==> musikloud_1.4.0.tar.gz: musikloud-1.4.0/musikloudapp/src/base/transfermanager.h <==
#ifndef TRANSFERMANAGER_H
#define TRANSFERMANAGER_H

#include "transferitem.h"
#include <QObject>

class TransferManager : public QObject
{
    Q_OBJECT

public:
    explicit TransferManager(QObject *parent = 0);
    ~TransferManager();
    inline QNetworkAccessManager* networkAccessManager() const { return m_nam; }
    inline void setNetworkAccessManager(QNetworkAccessManager *manager) { m_nam = manager; }
    Q_INVOKABLE void restoreStoredDownloads();
    Q_INVOKABLE int concurrentTransfers() const;
    Q_INVOKABLE inline int transferCount() const { return this->transferList()->size(); }
    inline QList< QSharedPointer<TransferItem> >* transferList() const { return m_transfers; }
    Q_INVOKABLE void addDownloadTransfer(TrackItem *track, bool notify = true);
    void addDownloadTransfer(QSharedPointer<TrackItem> track, bool notify = true);
    Q_INVOKABLE void addDownloadTransfer(PlaylistItem *playlist, QList<TrackItem*> tracks, bool notify = true);
    void addDownloadTransfer(QSharedPointer<PlaylistItem> playlist, QList< QSharedPointer<TrackItem> >tracks, bool notify = true);
    Q_INVOKABLE void addDownloadTransfers(QList<TrackItem*> tracks);
    void addDownloadTransfers(QList< QSharedPointer<TrackItem> >tracks);

    static TransferManager* instance();

public slots:
    void onMaximumConcurrentTransfersChanged(int oldMaximum, int newMaximum);

private:
    QString generateTransferId(QString seedFileName) const;
    QSharedPointer<TransferItem> getNextTransfer() const;
    QSharedPointer<TransferItem> getTransfer(TransferItem *transfer) const;
    bool removeTransfer(QSharedPointer<TransferItem> transfer);

private slots:
    void onTransferStatusChanged(Transfers::TransferStatus status);
    void onTransferCompleted(QSharedPointer<TransferItem> transfer);
    void onTransferCancelled(QSharedPointer<TransferItem> transfer);
    
signals:
    void alert(const QString &message);
    void transferRemoved(int row);

private:
    QNetworkAccessManager *m_nam;
    QList< QSharedPointer<TransferItem> > *m_transfers;
};

#endif // TRANSFERMANAGER_H

==> musikloud_1.4.1.tar.gz: musikloud-1.4.1/musikloudapp/src/base/transfermanager.h <==
#ifndef TRANSFERMANAGER_H
#define TRANSFERMANAGER_H

#include <QObject>
#include <qplatformdefs.h>
#ifdef MEEGO_EDITION_HARMATTAN
#include "../harmattan/transferitem.h"
#include <TransferUI/Client>
#elif (defined (Q_WS_MAEMO_5))
#include "../maemo5/transferitem.h"
#elif (defined (SYMBIAN_OS))
#include "../symbian/transferitem.h"
#endif

#ifdef MEEGO_EDITION_HARMATTAN
using namespace TransferUI;
#endif

class TransferManager : public QObject
{
    Q_OBJECT

public:
    explicit TransferManager(QObject *parent = 0);
    ~TransferManager();
    inline QNetworkAccessManager* networkAccessManager() const { return m_nam; }
    inline void setNetworkAccessManager(QNetworkAccessManager *manager) { m_nam = manager; }
    Q_INVOKABLE void restoreStoredDownloads();
    Q_INVOKABLE int concurrentTransfers() const;
    Q_INVOKABLE inline int transferCount() const { return this->transferList()->size(); }
    inline QList< QSharedPointer<TransferItem> >* transferList() const { return m_transfers; }
    Q_INVOKABLE void addDownloadTransfer(TrackItem *track, bool notify = true);
    void addDownloadTransfer(QSharedPointer<TrackItem> track, bool notify = true);
    Q_INVOKABLE void addDownloadTransfer(PlaylistItem *playlist, QList<TrackItem*> tracks, bool notify = true);
    void addDownloadTransfer(QSharedPointer<PlaylistItem> playlist, QList< QSharedPointer<TrackItem> >tracks, bool notify = true);
    Q_INVOKABLE void addDownloadTransfers(QList<TrackItem*> tracks);
    void addDownloadTransfers(QList< QSharedPointer<TrackItem> >tracks);
#ifdef MEEGO_EDITION_HARMATTAN
    Q_INVOKABLE inline bool harmattanTransferUIVisible() const { return !m_transferUI ? false : m_transferUI->isTUIVisible(); }
#endif
    static TransferManager* instance();

public slots:
    void onMaximumConcurrentTransfersChanged(int oldMaximum, int newMaximum);

private:
    QString generateTransferId(QString seedFileName) const;
    QSharedPointer<TransferItem> getNextTransfer() const;
    QSharedPointer<TransferItem> getTransfer(TransferItem *transfer) const;
    bool removeTransfer(QSharedPointer<TransferItem> transfer);

private slots:
    void onTransferStatusChanged(Transfers::TransferStatus status);
    void onTransferCompleted(QSharedPointer<TransferItem> transfer);
    void onTransferCancelled(QSharedPointer<TransferItem> transfer);
    
signals:
    void alert(const QString &message);
    void transferRemoved(int row);

private:
    QNetworkAccessManager *m_nam;
    QList< QSharedPointer<TransferItem> > *m_transfers;
#ifdef MEEGO_EDITION_HARMATTAN
    Client *m_transferUI;
#endif
};

#endif // TRANSFERMANAGER_H
